pub enum ReadinessSeverity {
Blocker,
Warning,
}Expand description
Severity of an electrical-readiness finding.
Variants
Blocker
The network must not be passed to numerical lowering or solving.
Warning
The network can be used, but the caller should inspect the finding.